<template>
  <el-dialog
    width="85%"
    title="订单合并列表"
    top="5vh"
    :visible.sync="innerVisible"
    append-to-body
    @close="$emit('update:currshowlist', false)"
    :show="currshowlist"
    class="order-merge-dialog"
    :close-on-click-modal="false"
  >
    <div>
      <div
        style="font-size:14px;font-weight:bold;color:black;height:30px;line-height:30px;"
      >
        待合并列表
      </div>
    </div>
    <el-table
      :data="orderMergeList"
      style="width: 100%;"
      height="240px"
      border
      stripe
      highlight-current-row
      @current-change="handleCurrentChange"
    >
      <el-table-column
        prop="moNo"
        label="车间订单号"
        align="center"
        show-overflow-tooltip
      >
      </el-table-column>
      <el-table-column
        prop="mpsNo"
        label="生产计划号"
        align="center"
        show-overflow-tooltip
      >
      </el-table-column>
      <el-table-column
        prop="partNo"
        label="零件号"
        align="center"
        show-overflow-tooltip
      >
      </el-table-column>
      <el-table-column
        prop="partName"
        label="零件名称"
        align="center"
        show-overflow-tooltip
      >
      </el-table-column>
      <el-table-column
        prop="qtyRequired"
        label="需求数量"
        width="80px"
        align="center"
      >
      </el-table-column>
      <el-table-column
        prop="requiredDate"
        label="需求日期"
        width="130px"
        align="center"
      >
      </el-table-column>
      <el-table-column
        prop="remark"
        label="备注"
        align="center"
        show-overflow-tooltip
      >
      </el-table-column>
      <el-table-column prop="ifsOrderNo" label="IFS订单号" align="center">
      </el-table-column>
      <el-table-column prop="ifsReleaseNo" label="IFS下达号" align="center">
      </el-table-column>
      <el-table-column prop="ifsSequenceNo" label="IFS序列号" align="center">
      </el-table-column>
      <el-table-column prop="startDate" label="开始日期" align="center">
      </el-table-column>
      <el-table-column prop="endDate" label="到期日" align="center">
      </el-table-column>
      <el-table-column
        prop="createTime"
        label="创建时间"
        align="center"
        show-overflow-tooltip
      >
      </el-table-column>
    </el-table>
    <div style="margin-top:10px;">
      <div
        style="font-size:14px;font-weight:bold;color:black;height:30px;line-height:30px;"
      >
        目标订单
      </div>
    </div>
    <el-table
      :data="targetOrderList"
      style="width: 100%;"
      height="120px"
      border
      stripe
    >
      <el-table-column
        prop="moNo"
        label="车间订单号"
        align="center"
        show-overflow-tooltip
      >
      </el-table-column>
      <el-table-column
        prop="mpsNo"
        label="生产计划号"
        align="center"
        show-overflow-tooltip
      >
      </el-table-column>
      <el-table-column
        prop="partNo"
        label="零件号"
        align="center"
        show-overflow-tooltip
      >
      </el-table-column>
      <el-table-column
        prop="partName"
        label="零件名称"
        align="center"
        show-overflow-tooltip
      >
      </el-table-column>
      <el-table-column
        prop="qtyRequired"
        label="需求数量"
        width="120px"
        align="center"
      >
        <template slot-scope="scope">
          <el-input
            v-model="scope.row.qtyRequired"
            @blur="blurChangeCallback(scope.row)"
          ></el-input>
        </template>
      </el-table-column>
      <el-table-column
        prop="requiredDate"
        label="需求日期"
        width="193px"
        align="center"
      >
        <template slot-scope="scope">
          <el-date-picker
            v-model="scope.row.requiredDate"
            style="width: 100%"
            type="datetime"
            placeholder="需求日期"
            value-format="yyyy-MM-dd HH:mm:ss"
          >
          </el-date-picker>
        </template>
      </el-table-column>
      <el-table-column prop="ifsOrderNo" label="IFS订单号" align="center">
      </el-table-column>
      <el-table-column prop="ifsReleaseNo" label="IFS下达号" align="center">
      </el-table-column>
      <el-table-column prop="ifsSequenceNo" label="IFS序列号" align="center">
      </el-table-column>
      <el-table-column prop="startDate" label="开始日期" align="center">
      </el-table-column>
      <el-table-column prop="endDate" label="到期日" align="center">
      </el-table-column>
      <el-table-column
        prop="createTime"
        label="创建时间"
        align="center"
        show-overflow-tooltip
      >
      </el-table-column>
    </el-table>
    <div slot="footer" class="dialog-footer">
      <el-button @click="innerVisible = false">取 消</el-button>
      <el-button
        type="primary"
        :disabled="isSubmit"
        v-thinclick="`saveSelectRow`"
        >确 定</el-button
      >
    </div>
  </el-dialog>
</template>
<script>
import { mergeUpdate } from '@/api/plan/manufacturingorder'
export default {
  props: {
    currshowlist: {
      type: Boolean,
      default: false
    },
    orderList: {
      type: Array,
      default: () => {
        return []
      }
    }
  },
  data() {
    return {
      innerVisible: false,
      isSubmit: false,
      orderMergeList: [],
      targetOrderList: []
    }
  },
  created() {},
  methods: {
    handleCurrentChange(row) {
      if (row != null) {
        this.createTargetOrderList(row)
      }
    },
    createTargetOrderList(row) {
      this.targetOrderList = []
      let qtyRequired = 0
      this.orderMergeList.forEach((item) => {
        qtyRequired = Number(
          (qtyRequired + Number(item.qtyRequired)).toFixed(6)
        )
      })
      this.targetOrderList.push({
        id: row.id,
        moNo: row.moNo,
        mpsNo: row.mpsNo,
        partNo: row.partNo,
        partName: row.partName,
        qtyRequired: qtyRequired,
        requiredDate: row.requiredDate,
        remark: row.remark,
        ifsOrderNo: row.ifsOrderNo,
        ifsReleaseNo: row.ifsReleaseNo,
        ifsSequenceNo: row.ifsSequenceNo,
        startDate: row.startDate,
        endDate: row.endDate,
        createTime: row.createTime
      })
    },
    blurChangeCallback(row) {
      this.checkQuality()
    },
    checkQuality() {
      // 勾选合计校验，是否大于需求数量
      let flag = true
      let flagMsg = ''
      for (let i = 0; i < this.targetOrderList.length; i++) {
        if (
          this.targetOrderList[i].qtyRequired == null ||
          this.targetOrderList[i].qtyRequired == ''
        ) {
          flag = false
          flagMsg = flagMsg + '需求数量不能为空；'
        } else {
          if (!this.checkZero(this.targetOrderList[i].qtyRequired)) {
            flag = false
            flagMsg = flagMsg + '需求数量不能为0；'
          } else {
            if (!this.checkPositive(this.targetOrderList[i].qtyRequired)) {
              flag = false
              flagMsg = flagMsg + '需求数量需为正数；'
            } else {
              if (!this.checkDecimal(this.targetOrderList[i].qtyRequired)) {
                flag = false
                flagMsg = flagMsg + '需求数量最多六位小数；'
              }
            }
          }
        }
      }
      if (!flag) {
        this.$message.error(flagMsg)
      }
      return flag
    },
    checkZero(value) {
      if (value == 0) {
        return false
      } else {
        return true
      }
    },
    checkPositive(value) {
      if (!/^[0-9]+.?[0-9]*$/.test(value)) {
        return false
      } else {
        return true
      }
    },
    checkDecimal(value) {
      if (
        !/(^[1-9]([0-9]+)?(\.[0-9]{1,6})?$)|(^(0){1}$)|(^[0-9]\.[0-9]{1,6}$)/.test(
          value
        )
      ) {
        return false
      } else {
        return true
      }
    },
    checkField() {
      let flag = true
      let flagMsg = ''
      for (let i = 0; i < this.targetOrderList.length; i++) {
        if (
          this.targetOrderList[i].requiredDate == null ||
          this.targetOrderList[i].requiredDate == ''
        ) {
          flag = false
          flagMsg = flagMsg + '需求日期不能为空；'
        }
      }
      if (!flag) {
        this.$message.error(flagMsg)
      }
      return flag
    },
    saveSelectRow() {
      if (this.targetOrderList.length > 0) {
        this.isSubmit = true
        let flag = this.checkQuality()
        if (flag) {
          flag = this.checkField()
          if (flag) {
            const mergeIds = []
            this.orderMergeList.forEach((item) => {
              mergeIds.push(item.id)
            })
            const targetOrder = this.targetOrderList[0]
            const orderObj = {
              id: targetOrder.id,
              qtyRequired: targetOrder.qtyRequired,
              requiredDate: targetOrder.requiredDate,
              mergeIds: mergeIds
            }
            mergeUpdate(orderObj)
              .then((response) => {
                const resData = response.data
                if (resData.code === 0) {
                  this.innerVisible = false
                  this.$message.success('订单合并成功')
                  this.$emit('refreshDataList')
                } else {
                  this.$message.error('订单合并失败')
                }
                this.isSubmit = false
              })
              .catch(() => {
                this.isSubmit = false
              })
          } else {
            this.isSubmit = false
          }
        } else {
          this.isSubmit = false
        }
      } else {
        this.$message.error('请选择需要合并的目标订单')
      }
    }
  },
  watch: {
    currshowlist() {
      this.innerVisible = this.currshowlist
      if (this.currshowlist) {
        this.orderMergeList = []
        this.targetOrderList = []
        this.$nextTick(() => {
          this.orderList.forEach((item) => {
            this.orderMergeList.push({
              id: item.id,
              moNo: item.moNo,
              mpsNo: item.mpsNo,
              partNo: item.partNo,
              partName: item.partName,
              qtyRequired: item.qtyRequired,
              requiredDate: item.requiredDate,
              remark: item.remark,
              ifsOrderNo: item.ifsOrderNo,
              ifsReleaseNo: item.ifsReleaseNo,
              ifsSequenceNo: item.ifsSequenceNo,
              startDate: item.startDate,
              endDate: item.endDate,
              createTime: item.createTime
            })
          })
        })
      }
    }
  }
}
</script>
<style>
.order-merge-dialog .el-dialog__header {
  padding: 10px 20px 10px;
}
.order-merge-dialog .el-dialog__header .el-dialog__headerbtn {
  top: 10px;
}
.order-merge-dialog .el-dialog__body {
  padding: 5px 20px;
}

.order-merge-dialog .el-dialog__footer {
  padding: 5px 20px 10px;
}

.order-merge-dialog .el-dialog__body .avue-crud__pagination {
  margin-top: 0px;
  margin-bottom: 5px;
}
</style>
